Package: HelpersMG
Type: Package
Title: Tools for Various R Functions Helpers
Version: 2026.8.24
Date: 2026-08-24
Authors@R: person(given = "Marc",
                    family = "Girondot",
                    role = c("aut", "cre"),
                    email = "marc.girondot@gmail.com", 
                    comment = c(ORCID = "0000-0001-6645-8530"))
Depends: R (>= 4.1), MASS, rlang, coda, Matrix, ggplot2
Suggests: lme4, RNetCDF, ncdf4, maps, fields, shiny, ppcor, pbmcapply,
        pbapply, parallel, visNetwork, igraph, shinyWidgets, cranlogs
Description: Contains miscellaneous functions useful for managing 'NetCDF' files (see <https://en.wikipedia.org/wiki/NetCDF>), get moon phase and time for sun rise and fall, tide level, analyse and reconstruct periodic time series of temperature with irregular sinusoidal pattern, show scales and wind rose in plot with change of color of text, Metropolis-Hastings algorithm for Bayesian MCMC analysis, plot graphs or boxplot with error bars, search files in disk by there names or their content, read the contents of all files from a folder at one time.
License: GPL-2
LazyLoad: yes
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-08-24 12:32:08 UTC; marcgirondot
Config/roxygen2/version: 8.1.0
Author: Marc Girondot [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6645-8530>)
Maintainer: Marc Girondot <marc.girondot@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-24 13:10:02 UTC
