# Generated by roxygen2: do not edit by hand

S3method("+",PriorsmcmcComposite)
S3method(as.mcmc,mcmcComposite)
S3method(logLik,LD50)
S3method(logLik,compareAIC)
S3method(logLik,cutter)
S3method(merge,mcmcComposite)
S3method(plot,IconoCorel)
S3method(plot,LD50)
S3method(plot,PriorsmcmcComposite)
S3method(plot,cutter)
S3method(plot,mcmcComposite)
S3method(predict,LD50)
S3method(print,cutter)
S3method(summary,mcmcComposite)
export(ChangeCoordinate)
export(DIx)
export(ELPDweight)
export(ExtractAIC.glm)
export(FormatCompareAIC)
export(IC_clean_data)
export(IC_correlation_simplify)
export(IC_threshold_matrix)
export(LD50)
export(LD50_MHmcmc)
export(LD50_MHmcmc_p)
export(MHalgoGen)
export(MovingWindow)
export(NagelkerkeScaledR2)
export(RM_add)
export(RM_delete)
export(RM_duplicate)
export(RM_get)
export(RM_list)
export(RandomFromHessianOrMCMC)
export(RectangleRegression)
export(SEfromHessian)
export(ScalePreviousPlot)
export(addS3Class)
export(as.parameters)
export(as.quantiles)
export(asc)
export(barplot_errbar)
export(cArrows)
export(char)
export(compare)
export(compare_AIC)
export(compare_AICc)
export(compare_BIC)
export(contingencyTable.compare)
export(convert.tz)
export(cutter)
export(d)
export(dSnbinom)
export(dbeta_new)
export(dcutter)
export(dggamma)
export(dnbinom_new)
export(duplicated_packages)
export(ellipse)
export(fitdistrquantiles)
export(flexit)
export(format_ncdf)
export(from_min_max)
export(iCutter)
export(ind_long_lat)
export(index.periodic)
export(inside)
export(invlogit)
export(list.packages)
export(local.search)
export(logit)
export(minmax.periodic)
export(modeled.hist)
export(modifyVector)
export(moon.info)
export(newcompassRose)
export(newmap.scale)
export(openwd)
export(pSnbinom)
export(pggamma)
export(plot_add)
export(plot_errbar)
export(qSnbinom)
export(qggamma)
export(qvlmer)
export(r2norm)
export(rSnbinom)
export(rcutter)
export(read_folder)
export(rggamma)
export(rmnorm)
export(rnbinom_new)
export(series.compare)
export(setPriors)
export(setPriors1)
export(show_name)
export(similar)
export(specify_decimal)
export(sun.info)
export(symbol.Female)
export(symbol.Male)
export(symmetricize)
export(tide.info)
export(tnirp)
export(universalmclapply)
export(wget)
import(coda)
importFrom(rlang,.data)
importFrom("grDevices", "rgb",  "colorRampPalette")
importFrom("graphics", "arrows", "axis", "barplot", "hist", "legend",
             "lines", "mtext", "par", "plot", "polygon", "segments", "points", 
             "xspline", "xyinch", "strheight", "text", "locator")
importFrom("stats", "AIC", "aggregate", "as.formula", "binomial", "density", 
             "dgamma", "pgamma", "qgamma", "rgamma", "optimise", 
             "dlnorm", "qlnorm", "plnorm", "rlnorm", 
             "dnorm", "pnorm", "qnorm", "rnorm", 
             "pbinom", "qbinom", "qchisq", "uniroot", 
             "coef", "cor", "dbeta", "dbinom", "deriv", "df.residual", 
             "dmultinom", "dnbinom", "glm", "lm", "logLik", 
             "na.omit", "numericDeriv", "optim", "pchisq", "qf", 
             "qt", "quantile", "residuals", "rnbinom", 
             "runif", "sd", "vcov", "cov", "cov2cor", "pt", "var", 
             "model.matrix", "terms", "median", "qbeta", 
             "dweibull", "pweibull", "qweibull", "rweibull", 
             "p.adjust", "rexp")
importFrom("utils", "combn", "download.file", "getFromNamespace",
             "installed.packages", "modifyList", "read.delim",
             "setTxtProgressBar", "tail", "txtProgressBar", 
             "compareVersion", "timestamp", "capture.output")
importFrom("Matrix", "nearPD")
importFrom("MASS", "ginv")
importFrom("ggplot2", "ggplot", "geom_line", "aes")
importFrom("rlang", ".data")
