% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/d.R
\name{d}
\alias{d}
\title{Write an ASCII Representation of a vector object}
\usage{
d(
  x,
  file = "",
  control = c("keepNA", "keepInteger", "showAttributes"),
  collapse = ", \\n  "
)
}
\arguments{
\item{x}{A named vector object}

\item{file}{either a character string naming a file or a connection. "" indicates output to the console.}

\item{control}{character vector indicating deparsing options. See .deparseOpts for their description.}

\item{collapse}{Characters used to separate values.}
}
\value{
A string
}
\description{
Writes an ASCII text representation of an R object.\cr
It can be used as a replacement of dput() for named vectors.\cr
The controls "keepNA", "keepInteger" and "showAttributes" are utilized for named vectors.
}
\details{
d Write an ASCII Representation of a vector object
}
\examples{
d(c(A=10, B=20))
dput(c(A=10, B=20))
}
\seealso{
Other Characters:
\code{\link[=asc]{asc()}},
\code{\link[=char]{char()}},
\code{\link[=tnirp]{tnirp()}}
}
\author{
Marc Girondot \email{marc.girondot@gmail.com}
}
\concept{Characters}
