% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AddPriors.R
\name{+.PriorsmcmcComposite}
\alias{+.PriorsmcmcComposite}
\title{Set priors for MHalgoGen()}
\usage{
\method{+}{PriorsmcmcComposite}(prior1, prior2)
}
\arguments{
\item{prior1}{The first prior.}

\item{prior2}{The second prior.}
}
\value{
Return a data.frame with the formatted priors
}
\description{
Construct priors for MHalgoGen()\cr
A check is done to verify that parameter names are not duplicated.
}
\details{
+.PriorsmcmcComposite is a general function to set priors for MHalgoGen()
}
\examples{
\dontrun{
library(HelpersMG)
Priors <- setPriors1(Name="a0", Prior1=0, Prior2=1, Density="dunif", 
                     SDProp=0.1, Min=0, Max=1, Init=0.5)
Priors <- Priors + setPriors1(Name="a1", Prior1=0.5, Prior2=0.1, Density="dnorm", 
                     SDProp=0.05, Min=0, Max=1, Init=0.5)
# Using Parameters
Priors <- setPriors1(Name="a0", Parameters=c(min=0, max=1), Density="dunif", 
                     SDProp=0.1, Min=0, Max=1, Init=0.5)
Priors <- Priors + setPriors1(Name="a1", Parameters=c(mean=0.5, sd=0.1), Density="dnorm", 
                     SDProp=0.05, Min=0, Max=1, Init=0.5)
}
}
\seealso{
Other mcmcComposite functions:
\code{\link[=MHalgoGen]{MHalgoGen()}},
\code{\link[=PPD]{PPD()}},
\code{\link[=as.mcmc.mcmcComposite]{as.mcmc.mcmcComposite()}},
\code{\link[=as.parameters]{as.parameters()}},
\code{\link[=merge.mcmcComposite]{merge.mcmcComposite()}},
\code{\link[=plot.PriorsmcmcComposite]{plot.PriorsmcmcComposite()}},
\code{\link[=plot.mcmcComposite]{plot.mcmcComposite()}},
\code{\link[=setPriors]{setPriors()}},
\code{\link[=setPriors1]{setPriors1()}},
\code{\link[=summary.mcmcComposite]{summary.mcmcComposite()}}
}
\author{
Marc Girondot \email{marc.girondot@gmail.com}
}
\concept{mcmcComposite functions}
